## Math Data

### Constants
pi=3.14159265359

phi=1.6180339887


### Highly Composite Numbers
1, 2, 4, 6, 12, 24, 36, 48, 60, 120, 180, 240, 360, 720, 840, 1260, 1680, 2520, 5040, 7560, 10080, 15120, 20160, 25200, 27720, 45360, 50400, 55440, 83160, 110880, 166320, 221760, 277200, 332640, 498960, 554400, 665280, 720720, 1081080, 1441440, 2162160

### Practical Numbers
Barrel.css uses these numbers for sizing.

1, 2, 4, 6, 8, 12, 16, 18, 20, 24, 28, 30, 32, 36, 40, 42, 48, 54, 56, 60, 64, 66, 72, 78, 80, 84, 88, 90, 96, 100, 104, 108, 112, 120, 126, 128, 132, 140, 144, 150....

### 5-smooth numbers
1, 2, 3, 4, 5, 6, 8, 9, 10, 12, 15, 16, 18, 20, 24, 25, 27, 30, 32, 36, 40, 45, 48, 50, 54, 60, 64, 72, 75, 80, 81, 90, 96, 100, 108, 120, 125, 128, 135, 144, 150, 160, 162, 180, 192, 200, 216, 225, 240, 243, 250, 256, 270, 288, 300, 320, 324, 360, 375, 384, 400, 405


### Roman Numerals

1=I, 2=II, 3=III, 4=IV, 5=V
6=VI, 7=VII, 8=VIII, 9=IX, 10=X
11=XI, 12=XII, 13=XIII, 14=XIV, 15=XV
16=XVI, 17=XVII, 18=XVIII, 19=XIX, 20=XX
21=XXI, 22=XXII, 23=XXIII, 24=XXIV, 25=XXV
26=XXVI, 27=XXVII, 28=XXVIII, 29=XXIX, 30=XXX
31=XXXI, 32=XXXII, 33=XXXIII, 34=XXXIV, 35=XXXV
36=XXXVI, 37=XXXVII, 38=XXXVIII, 39=XXXIX, 40=XL
41=XLI, 42=XLII, 43=XLIII, 44=XLIV, 45=XLV
46=XLVI, 47=XLVII, 48=XLVIII, 49=XLIX, 50=L
51=LI, 52=LII, 53=LIII, 54=LIV, 55=LV
56=LVI, 57=LVII, 58=LVIII, 59=LIX, 60=LX
61=LXI, 62=LXII, 63=LXIII, 64=LXIV, 65=LXV
66=LXVI, 67=LXVII, 68=LXVIII, 69=LXIX, 70=LXX
71=LXXI, 72=LXXII, 73=LXXIII, 74=LXXIV, 75=LXXV
76=LXXVI, 77=LXXVII, 78=LXXVIII, 79=LXXIX, 80=LXXX
81=LXXXI, 82=LXXXII, 83=LXXXIII, 84=LXXXIV, 85=LXXXV
86=LXXXVI, 87=LXXXVII, 88=LXXXVIII, 89=LXXXIX, 90=XC
91=XCI, 92=XCII, 93=XCIII, 94=XCIV, 95=XCV
96=XCVI, 97=XCVII, 98=XCVIII, 99=XCIX, 100=C

## Conversions

### dBm to mW

 | dBm     | mW                |
 | ------- | ----------------- |
 | -40 dBm | 0.0001 mW         |
 | -30 dBm | 0.001 mW          |
 | -20 dBm | 0.01 mW           |
 | -10 dBm | 0.1 mW            |
 | 0 dBm   | 1 mW              |
 | 1 dBm   | 1.25 mW           |
 | 2 dBm   | 1.58 mW           |
 | 3 dBm   | 1.99 mW           |
 | 4 dBm   | 2.51 mW           |
 | 5 dBm   | 3.16 mW           |
 | 6 dBm   | 3.98 mW           |
 | 7 dBm   | 5.01 mW           |
 | 8 dBm   | 6.30 mW           |
 | 9 dBm   | 7.94 mW           |
 | 10 dBm  | 10 mW             |
 | 20 dBm  | 100 mW            |
 | 30 dBm  | 1000 mW           |
 | 33 dBm  | 1995 mW (~2W)     |
 | 36 dBm  | 3981 mW (~4W)     |
 | 40 dBm  | 10,000 mW (10W)   |
 | 50 dBm  | 100,000 mW (100W) |


![Reference, CC0](/static/docs/img/knots_reference_1.webp)


## US Wood Screw Sizes

| Size | Driver(PH) | Head Max | Head Max(mm) | Head Min | Head Min(mm) | Head Height | Head Height(mm) | Diameter Max | Diameter Max(mm) | Diameter Min | Diameter Min(mm) |
| ---- | ---------- | -------- | ------------ | -------- | ------------ | ----------- | --------------- | ------------ | ---------------- | ------------ | ---------------- |
| 2    | 1          | 0.172    | 4.3688       | 0.147    | 3.7338       | 0.051       | 1.2954          | 0.09         | 2.286            | 0.079        | 2.0066           |
| 3    | 1          | 0.199    | 5.0546       | 0.141    | 3.5814       | 0.059       | 1.4986          | 0.103        | 2.6162           | 0.092        | 2.3368           |
| 4    | 1          | 0.225    | 5.715        | 0.195    | 4.953        | 0.067       | 1.7018          | 0.116        | 2.9464           | 0.105        | 2.667            |
| 5    | 2          | 0.252    | 6.4008       | 0.22     | 5.588        | 0.075       | 1.905           | 0.129        | 3.2766           | 0.118        | 2.9972           |
| 6    | 2          | 0.279    | 7.0866       | 0.244    | 6.1976       | 0.083       | 2.1082          | 0.142        | 3.6068           | 0.131        | 3.3274           |
| 7    | 2          | 0.305    | 7.747        | 0.268    | 6.8072       | 0.091       | 2.3114          | 0.155        | 3.937            | 0.144        | 3.6576           |
| 8    | 2          | 0.332    | 8.4328       | 0.292    | 7.4168       | 0.1         | 2.54            | 0.168        | 4.2672           | 0.157        | 3.9878           |
| 9    | 2          | 0.358    | 9.0932       | 0.316    | 8.0264       | 0.108       | 2.7432          | 0.181        | 4.5974           | 0.17         | 4.318            |
| 10   | 3          | 0.385    | 9.779        | 0.34     | 8.636        | 0.116       | 2.9464          | 0.194        | 4.9276           | 0.183        | 4.6482           |
| 12   | 3          | 0.438    | 11.1252      | 0.389    | 9.8806       | 0.132       | 3.3528          | 0.22         | 5.588            | 0.209        | 5.3086           |
| 14   | 3          | 0.507    | 12.8778      | 0.452    | 11.4808      | 0.153       | 3.8862          | 0.246        | 6.2484           | 0.235        | 5.969            |
| 16   | 3          | 0.544    | 13.8176      | 0.485    | 12.319       | 0.164       | 4.1656          | 0.272        | 6.9088           | 0.261        | 6.6294           |



## Paper Sizes

| Name | Metric        | Imperial      |
| ---- | ------------- | ------------- |
| 4A0  | 1682x2378mm   | 66.2x93.6in   |
| 2A0  | 1189x1682mm   | 46.8x66.2in   |
| A0   | 841x1189mm    | 33.1x46.8in   |
| A1   | 594x841mm     | 23.4x33.1in   |
| A2   | 420x594mm     | 16.5x23.4in   |
| A3   | 297x420mm     | 11.7x16.5in   |
| A4   | 210x297mm     | 8.3x11.7in    |
| A5   | 148x210mm     | 5.8x8.3in     |
| A6   | 105x148mm     | 4.1x5.8in     |
| A7   | 74x105mm      | 2.9x4.1in     |
| A8   | 52x74mm       | 2.0x2.9in     |
| A9   | 37x52mm       | 1.5x2.0in     |
| A10  | 26x37mm       | 1.0x1.5in     |
| ID-1 | 53.98 x 85.60 | 3.370 × 2.125 |


| Name              | Metric    | Imperial    | Ratio    |
| ----------------- | --------- | ----------- | -------- |
| Half Letter       | 140x216mm | 5.5x8.5in   | 1:1.5455 |
| Government Letter | 203x254mm | 8.0x10.0in  | 1:1.25   |
| Letter            | 216x279mm | 8.5x11.0in  | 1:1.2941 |
| Jr. Legal         | 127x203mm | 5.0x8.0in   | 1:1.6000 |
| Government Legal  | 216x330mm | 8.5x13.0in  | 1:1.5294 |
| Legal             | 216x356mm | 8.5x14.0in  | 1:1.6471 |
| Ledger / Tabloid  | 279x432mm | 11.0x17.0in | 1:1.5455 |

## ASCII

| Dec | Hex | Binary   | Char     |
| --- | --- | -------- | -------- |
| 0   | 00  | 00000000 | NUL      |
| 1   | 01  | 00000001 | SOH      |
| 2   | 02  | 00000010 | STX      |
| 3   | 03  | 00000011 | ETX      |
| 4   | 04  | 00000100 | EOT      |
| 5   | 05  | 00000101 | ENQ      |
| 6   | 06  | 00000110 | ACK      |
| 7   | 07  | 00000111 | BEL      |
| 8   | 08  | 00001000 | BS       |
| 9   | 09  | 00001001 | HT       |
| 10  | 0A  | 00001010 | LF       |
| 11  | 0B  | 00001011 | VT       |
| 12  | 0C  | 00001100 | FF       |
| 13  | 0D  | 00001101 | CR       |
| 14  | 0E  | 00001110 | SO       |
| 15  | 0F  | 00001111 | SI       |
| 16  | 10  | 00010000 | DLE      |
| 17  | 11  | 00010001 | DC1      |
| 18  | 12  | 00010010 | DC2      |
| 19  | 13  | 00010011 | DC3      |
| 20  | 14  | 00010100 | DC4      |
| 21  | 15  | 00010101 | NAK      |
| 22  | 16  | 00010110 | SYN      |
| 23  | 17  | 00010111 | ETB      |
| 24  | 18  | 00011000 | CAN      |
| 25  | 19  | 00011001 | EM       |
| 26  | 1A  | 00011010 | SUB      |
| 27  | 1B  | 00011011 | ESC      |
| 28  | 1C  | 00011100 | FS       |
| 29  | 1D  | 00011101 | GS       |
| 30  | 1E  | 00011110 | RS       |
| 31  | 1F  | 00011111 | US       |
| 32  | 20  | 00100000 | space    |
| 33  | 21  | 00100001 | !        |
| 34  | 22  | 00100010 | "        |
| 35  | 23  | 00100011 | #        |
| 36  | 24  | 00100100 | $        |
| 37  | 25  | 00100101 | %        |
| 38  | 26  | 00100110 | &        |
| 39  | 27  | 00100111 | '        |
| 40  | 28  | 00101000 | (        |
| 41  | 29  | 00101001 | )        |
| 42  | 2A  | 00101010 | *        |
| 43  | 2B  | 00101011 | +        |
| 44  | 2C  | 00101100 | ,        |
| 45  | 2D  | 00101101 | -        |
| 46  | 2E  | 00101110 | .        |
| 47  | 2F  | 00101111 | /        |
| 48  | 30  | 00110000 | 0        |
| 49  | 31  | 00110001 | 1        |
| 50  | 32  | 00110010 | 2        |
| 51  | 33  | 00110011 | 3        |
| 52  | 34  | 00110100 | 4        |
| 53  | 35  | 00110101 | 5        |
| 54  | 36  | 00110110 | 6        |
| 55  | 37  | 00110111 | 7        |
| 56  | 38  | 00111000 | 8        |
| 57  | 39  | 00111001 | 9        |
| 58  | 3A  | 00111010 | :        |
| 59  | 3B  | 00111011 | ;        |
| 60  | 3C  | 00111100 | <        |
| 61  | 3D  | 00111101 | =        |
| 62  | 3E  | 00111110 | >        |
| 63  | 3F  | 00111111 | ?        |
| 64  | 40  | 01000000 | @        |
| 65  | 41  | 01000001 | A        |
| 66  | 42  | 01000010 | B        |
| 67  | 43  | 01000011 | C        |
| 68  | 44  | 01000100 | D        |
| 69  | 45  | 01000101 | E        |
| 70  | 46  | 01000110 | F        |
| 71  | 47  | 01000111 | G        |
| 72  | 48  | 01001000 | H        |
| 73  | 49  | 01001001 | I        |
| 74  | 4A  | 01001010 | J        |
| 75  | 4B  | 01001011 | K        |
| 76  | 4C  | 01001100 | L        |
| 77  | 4D  | 01001101 | M        |
| 78  | 4E  | 01001110 | N        |
| 79  | 4F  | 01001111 | O        |
| 80  | 50  | 01010000 | P        |
| 81  | 51  | 01010001 | Q        |
| 82  | 52  | 01010010 | R        |
| 83  | 53  | 01010011 | S        |
| 84  | 54  | 01010100 | T        |
| 85  | 55  | 01010101 | U        |
| 86  | 56  | 01010110 | V        |
| 87  | 57  | 01010111 | W        |
| 88  | 58  | 01011000 | X        |
| 89  | 59  | 01011001 | Y        |
| 90  | 5A  | 01011010 | Z        |
| 91  | 5B  | 01011011 | [        |
| 92  | 5C  | 01011100 | \        |
| 93  | 5D  | 01011101 | ]        |
| 94  | 5E  | 01011110 | ^        |
| 95  | 5F  | 01011111 | _        |
| 96  | 60  | 01100000 | `        |
| 97  | 61  | 01100001 | a        |
| 98  | 62  | 01100010 | b        |
| 99  | 63  | 01100011 | c        |
| 100 | 64  | 01100100 | d        |
| 101 | 65  | 01100101 | e        |
| 102 | 66  | 01100110 | f        |
| 103 | 67  | 01100111 | g        |
| 104 | 68  | 01101000 | h        |
| 105 | 69  | 01101001 | i        |
| 106 | 6A  | 01101010 | j        |
| 107 | 6B  | 01101011 | k        |
| 108 | 6C  | 01101100 | l        |
| 109 | 6D  | 01101101 | m        |
| 110 | 6E  | 01101110 | n        |
| 111 | 6F  | 01101111 | o        |
| 112 | 70  | 01110000 | p        |
| 113 | 71  | 01110001 | q        |
| 114 | 72  | 01110010 | r        |
| 115 | 73  | 01110011 | s        |
| 116 | 74  | 01110100 | t        |
| 117 | 75  | 01110101 | u        |
| 118 | 76  | 01110110 | v        |
| 119 | 77  | 01110111 | w        |
| 120 | 78  | 01111000 | x        |
| 121 | 79  | 01111001 | y        |
| 122 | 7A  | 01111010 | z        |
| 123 | 7B  | 01111011 | {        |
| 124 | 7C  | 01111100 |          |
| 125 | 7D  | 01111101 | }        |
| 126 | 7E  | 01111110 | ~        |
| 127 |     | 7F       | 01111111 | DEL |

## Notes and Frequencies(440hz tuning)
| Name             | Frequency | MIDI note number |
| ---------------- | --------- | ---------------- |
| G9               | 12543.85  | 127              |
| F#9/Gb9          | 11839.82  | 126              |
| F9               | 11175.3   | 125              |
| E9               | 10548.08  | 124              |
| D#9/Eb9          | 9956.06   | 123              |
| D9               | 9397.27   | 122              |
| C#9/Db9          | 8869.84   | 121              |
| C9               | 8372.02   | 120              |
| B8               | 7902.13   | 119              |
| A#8/Bb8          | 7458.62   | 118              |
| A8               | 7040      | 117              |
| G#8/Ab8          | 6644.88   | 116              |
| G8               | 6271.93   | 115              |
| F#8/Gb8          | 5919.91   | 114              |
| F8               | 5587.65   | 113              |
| E8               | 5274.04   | 112              |
| D#8/Eb8          | 4978.03   | 111              |
| D8               | 4698.64   | 110              |
| C#8/Db8          | 4434.92   | 109              |
| C8               | 4186.01   | 108              |
| B7               | 3951.07   | 107              |
| A#7/Bb7          | 3729.31   | 106              |
| A7               | 3520      | 105              |
| G#7/Ab7          | 3322.44   | 104              |
| G7               | 3135.96   | 103              |
| F#7/Gb7          | 2959.96   | 102              |
| F7               | 2793.83   | 101              |
| E7               | 2637.02   | 100              |
| D#7/Eb7          | 2489.02   | 99               |
| D7               | 2349.32   | 98               |
| C#7/Db7          | 2217.46   | 97               |
| C7               | 2093      | 96               |
| B6               | 1975.53   | 95               |
| A#6/Bb6          | 1864.66   | 94               |
| A6               | 1760      | 93               |
| G#6/Ab6          | 1661.22   | 92               |
| G6               | 1567.98   | 91               |
| F#6/Gb6          | 1479.98   | 90               |
| F6               | 1396.91   | 89               |
| E6               | 1318.51   | 88               |
| D#6/Eb6          | 1244.51   | 87               |
| D6               | 1174.66   | 86               |
| C#6/Db6          | 1108.73   | 85               |
| C6               | 1046.5    | 84               |
| B5               | 987.77    | 83               |
| A#5/Bb5          | 932.33    | 82               |
| A5               | 880       | 81               |
| G#5/Ab5          | 830.61    | 80               |
| G5               | 783.99    | 79               |
| F#5/Gb5          | 739.99    | 78               |
| F5               | 698.46    | 77               |
| E5               | 659.26    | 76               |
| D#5/Eb5          | 622.25    | 75               |
| D5               | 587.33    | 74               |
| C#5/Db5          | 554.37    | 73               |
| C5               | 523.25    | 72               |
| B4               | 493.88    | 71               |
| A#4/Bb4          | 466.16    | 70               |
| A4 concert pitch | 440       | 69               |
| G#4/Ab4          | 415.3     | 68               |
| G4               | 392       | 67               |
| F#4/Gb4          | 369.99    | 66               |
| F4               | 349.23    | 65               |
| E4               | 329.63    | 64               |
| D#4/Eb4          | 311.13    | 63               |
| D4               | 293.66    | 62               |
| C#4/Db4          | 277.18    | 61               |
| C4 (middle C)    | 261.63    | 60               |
| B3               | 246.94    | 59               |
| A#3/Bb3          | 233.08    | 58               |
| A3               | 220       | 57               |
| G#3/Ab3          | 207.65    | 56               |
| G3               | 196       | 55               |
| F#3/Gb3          | 185       | 54               |
| F3               | 174.61    | 53               |
| E3               | 164.81    | 52               |
| D#3/Eb3          | 155.56    | 51               |
| D3               | 146.83    | 50               |
| C#3/Db3          | 138.59    | 49               |
| C3               | 130.81    | 48               |
| B2               | 123.47    | 47               |
| A#2/Bb2          | 116.54    | 46               |
| A2               | 110       | 45               |
| G#2/Ab2          | 103.83    | 44               |
| G2               | 98        | 43               |
| F#2/Gb2          | 92.5      | 42               |
| F2               | 87.31     | 41               |
| E2               | 82.41     | 40               |
| D#2/Eb2          | 77.78     | 39               |
| D2               | 73.42     | 38               |
| C#2/Db2          | 69.3      | 37               |
| C2               | 65.41     | 36               |
| B1               | 61.74     | 35               |
| A#1/Bb1          | 58.27     | 34               |
| A1               | 55        | 33               |
| G#1/Ab1          | 51.91     | 32               |
| G1               | 49        | 31               |
| F#1/Gb1          | 46.25     | 30               |
| F1               | 43.65     | 29               |
| E1               | 41.2      | 28               |
| D#1/Eb1          | 38.89     | 27               |
| D1               | 36.71     | 26               |
| C#1/Db1          | 34.65     | 25               |
| C1               | 32.7      | 24               |
| B0               | 30.87     | 23               |
| A#0/Bb0          | 29.14     | 22               |
| A0               | 27.5      | 21               |

## Regular Expressions

```
a-z, a-Z, 0-9, etc:  Matches literal character
*                 :  0 to unlimited repeats of previous
+                 :  1 to unlimited repeats
[]                :  Match anything in group, can use ranges like [a-Z]
?                 :  Modifies previous, tries to match as few as possible
()                :  Capturing group, whatever is in the parens is separated in output
$1, $2, etc       :  Refererence a capturing group
^                 :  Line start or string start
$                 :  Line end or string end
```

### Regex examples

```
Match an email:

^([a-z0-9_\.\+-]+)@([\da-z\.-]+)\.([a-z\.]{2,6})$

```

## Special address blocks

| Address block      | Address range               | Number of addresses | Scope         |
| ------------------ | --------------------------- | ------------------- | ------------- |
| 0.0.0.0/8          | 0.0.0.0–0.255.255.255       | 16777216            | Software      |
| 10.0.0.0/8         | 10.0.0.0–10.255.255.255     | 16777216            | Private       |
| 100.64.0.0/10      | 100.64.0.0–100.127.255.255  | 4194304             | Private       |
| 127.0.0.0/8        | 127.0.0.0–127.255.255.255   | 16777216            | Host          |
| 169.254.0.0/16     | 169.254.0.0–169.254.255.255 | 65536               | Subnet        |
| 172.16.0.0/12      | 172.16.0.0–172.31.255.255   | 1048576             | Private       |
| 192.0.0.0/24       | 192.0.0.0–192.0.0.255       | 256                 | Private       |
| 192.0.2.0/24       | 192.0.2.0–192.0.2.255       | 256                 | Documentation |
| 192.88.99.0/24     | 192.88.99.0–192.88.99.255   | 256                 | Internet      |
| 192.168.0.0/16     | 192.168.0.0–192.168.255.255 | 65536               | Private       |
| 198.18.0.0/15      | 198.18.0.0–198.19.255.255   | 131072              | Private       |
| 198.51.100.0/24    | 198.51.100.0–198.51.100.255 | 256                 | Documentation |
| 203.0.113.0/24     | 203.0.113.0–203.0.113.255   | 256                 | Documentation |
| 224.0.0.0/4        | 224.0.0.0–239.255.255.255   | 268435456           | Internet      |
| 233.252.0.0/24     | 233.252.0.0-233.252.0.255   | 256                 | Documentation |
| 240.0.0.0/4        | 240.0.0.0–255.255.255.254   | 268435455           | Internet      |
| 255.255.255.255/32 | 255.255.255.255             | 1                   | Subnet        | Broadcast |


| Address block (CIDR)     | First address    | Last address                            | Number of addresses         | Usage             |
| ------------------------ | ---------------- | --------------------------------------- | --------------------------- | ----------------- |
| ::/128                   | ::               | ::                                      | 1                           | Software          |
| ::1/128                  | ::1              | ::1                                     | 1                           | Host              |
| ::ffff:0:0/96            | ::ffff:0.0.0.0   | ::ffff:255.255.255.255                  | 232                         | Software          |
| ::ffff:0:0:0/96          | ::ffff:0:0.0.0.0 | ::ffff:0:255.255.255.255                | 232                         | Software          |
| 64:ff9b::/96             | 64:ff9b::0.0.0.0 | 64:ff9b::255.255.255.255                | 232                         | Global Internet   |
| 64:ff9b:1::/48           | 64:ff9b:1::      | 64:ff9b:1:ffff:ffff:ffff:ffff:ffff      | 280, with 248 for each IPv4 | Private internets |
| 100::/64                 | 100::            | 100::ffff:ffff:ffff:ffff                | 264                         | Routing           |
| 2001:0000::/32           | 2001::           | 2001::ffff:ffff:ffff:ffff:ffff:ffff     | 296                         | Global Internet   |
| 2001:20::/28             | 2001:20::        | 2001:2f:ffff:ffff:ffff:ffff:ffff:ffff   | 2100                        | Software          |
| 2001:db8::/32            | 2001:db8::       | 2001:db8:ffff:ffff:ffff:ffff:ffff:ffff  | 296                         | Documentation     |
| 2002::/16                | 2002::           | 2002:ffff:ffff:ffff:ffff:ffff:ffff:ffff | 2112                        | Global Internet   |
| fc00::/7                 | fc00::           | fdff:ffff:ffff:ffff:ffff:ffff:ffff:ffff | 2121                        | Private internets | Unique             |
| fe80::/64 from fe80::/10 | fe80::           | fe80::ffff:ffff:ffff:ffff               | 264                         | Link              | Link-local address |
| ff00::/8                 | ff00::           | ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff | 2120                        | Global Internet   | Multicast address  |


## Letters in Frequency Order

### English
ETAOINSRHDLUCMFYWGPBVKXQJZ

## NATO Phonetic Alphabet

| Letter | Word          | DIN                 | ICAO IPA                      | ICAO Pronunciation          |
| ------ | ------------- | ------------------- | ----------------------------- | --------------------------- |
| A      | Alfa [sic]    | ˈalfa               | ˈælfa                         | AL fah                      |
| B      | Bravo         | ˈbravo              | ˈbraːˈvo [sic]                | BRAH voh                    |
| C      | Charlie       | ˈtʃali or ˈʃali     | ˈtʃɑːli or ˈʃɑːli             | CHAR lee or SHAR lee        |
| D      | Delta         | ˈdɛlta              | ˈdeltɑ                        | DELL tah                    |
| E      | Echo          | ˈɛko                | ˈeko                          | ECK oh                      |
| F      | Foxtrot       | ˈfɔkstrɔt           | ˈfɔkstrɔt                     | FOKS trot                   |
| G      | Golf          | ˈɡɔlf               | ɡʌlf [sic]                    | golf                        |
| H      | Hotel         | hoˈtɛl              | hoːˈtel                       | ho TELL                     |
| I      | India         | ˈɪndia              | ˈindi.ɑ                       | IN dee ah                   |
| J      | Juliett [sic] | ˈdʒuliˈɛt           | ˈdʒuːli.ˈet                   | JEW lee ETT                 |
| K      | Kilo          | ˈkilo               | ˈkiːlo                        | KEY loh                     |
| L      | Lima          | ˈlima               | ˈliːmɑ                        | LEE mah                     |
| M      | Mike          | ˈmai̯k               | mɑik                          | mike                        |
| N      | November      | noˈvɛmba            | noˈvembə                      | no VEM ber                  |
| O      | Oscar         | ˈɔska               | ˈɔskɑ                         | OSS cah                     |
| P      | Papa          | paˈpa               | pəˈpɑ                         | pah PAH                     |
| Q      |               | Quebec              | keˈbɛk [sic]                  | keˈbek                      | keh BECK |
| R      | Romeo         | ˈromio              | ˈroːmi.o                      | ROW me oh                   |
| S      | Sierra        | siˈɛra              | siˈerɑ                        | see AIR rah                 |
| T      | Tango         | ˈtaŋɡo              | ˈtænɡo                        | TANG go                     |
| U      | Uniform       | ˈjunifɔm or ˈunifɔm | ˈjuːnifɔːm or ˈuːnifɔrm [sic] | YOU nee form or OO nee form |
| V      | Victor        | ˈvɪkta              | ˈviktɑ                        | VIK tah                     |
| W      | Whiskey       | ˈwɪski              | ˈwiski                        | WISS key                    |
| X      | Xray, x-ray   | ˈɛksrei̯             | ˈeksˈrei [sic]                | ECKS ray                    |
| Y      | Yankee        | ˈjaŋki              | ˈjænki                        | YANG key                    |
| Z      | Zulu          | ˈzulu               | ˈzuːluː                       | ZOO loo                     |

## Q Codes

| Code | Meaning                                                                                                                                                         |
| ---- | --------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| QRG  | Your exact frequency (or that of ______) is _________kHz. Will you tell me my exact frequency (or that of __________)?                                          |
| QRL  | I am busy (or I am busy with _________). Are you busy? Usually used to see if a frequency is busy.                                                              |
| QRM  | Your transmission is being interfered with _________ (1. Nil; 2. Slightly; 3. Moderately; 4. Severely; 5. Extremely.) Is my transmission being interfered with? |
| QRN  | I am troubled by static _________. (1 to 5 as under QRM.) Are you troubled by static?                                                                           |
| QRO  | Increase power. Shall I increase power?                                                                                                                         |
| QRP  | Decrease power. Shall I decrease power?                                                                                                                         |
| QRQ  | Send faster (_________wpm). Shall I send faster?                                                                                                                |
| QRS  | Send more slowly (_________wpm). Shall I send more slowly?                                                                                                      |
| QRT  | Stop sending. Shall I stop sending?                                                                                                                             |
| QRU  | I have nothing for you. Have you anything for me?                                                                                                               |
| QRV  | I am ready. Are you ready?                                                                                                                                      |
| QRX  | I will call you again at ______hours (on ______kHz). When will you call me again? Minutes are usually implied rather than hours.                                |
| QRZ  | You are being called by _________ (on ______kHz). Who is calling me?                                                                                            |
| QSB  | Your signals are fading. Are my signals fading?                                                                                                                 |
| QSK  | I can hear you between signals; break in on my transmission. Can you hear me between your signals and if so can I break in on your transmission?                |
| QSL  | I am acknowledging receipt. Can you acknowledge receipt (of a message or transmission)?                                                                         |
| QSO  | I can communicate with _________ direct (or relay through ______). Can you communicate with ______ direct or by relay?                                          |
| QSP  | I will relay to ______. Will you relay to ______?                                                                                                               |
| QST  | General call preceding a message addressed to all amateurs and ARRL members. This is in effect "CQ ARRL."                                                       |
| QSX  | I am listening to ______ on ______kHz. Will you listen to ______on ______kHz?                                                                                   |
| QSY  | Change to transmission on another frequency (or on ______kHz). Shall I change to transmission on another frequency (or on ______kHz)?                           |
| QTC  | I have ______messages for you (or for ______). How many messages have you to send?                                                                              |
| QTH  | My location is _________. What is your location?                                                                                                                |
| QTR  | The time is _________. What is the correct time?                                                                                                                |

## Morse Code

```
          THE INTERNATIONAL MORSE CODE

A      ._                                U     .._
B      _...                              V     ..._
C      _._.                              W     .--
D      _..                               X     _.._
E      .                                 Y     _.__
F      .._.                              Z     __..
G      __.                               1     .____
H      ....                              2     ..___
I      ..                                3     ...__
J      .___                              4     ...._
K      _._                               5     .....
L      ._..                              6     _....
M      __                                7     __...
N      _.                                8     ___..
O      ___                               9     ____.
P      .__.                             10     _____
Q      __._                         Period     ._._._
R      ._.                           Comma     __..__
S      ...                   Question Mark     ..__..
T      _
```

## Galvanic Series

Least reactive at top. Metals that are far apart in the series may cause the lower one to corrode,
when they are touching in a humid environment.

* Graphite
* Palladium
* Platinum
* Gold
* Silver
* Titanium
* Stainless steel 316 (passive)
* Stainless Steel 304 (passive)
* Silicon bronze
* Stainless Steel 316 (active)
* Monel 400
* Phosphor bronze
* Admiralty brass
* Cupronickel
* Molybdenum
* Red brass
* Brass plating
* Yellow brass
* Naval brass 464
* Uranium 8% Mo
* Niobium 1% Zr
* Tungsten
* Tin
* Lead
* Stainless Steel 304 (active)
* Tantalum
* Chromium plating
* Nickel (passive)
* Copper
* Nickel (active)
* Cast iron
* Steel
* Indium
* Aluminum
* Uranium (pure)
* Cadmium
* Beryllium
* Zinc plating (see galvanization)
* Magnesium

## Anode and Cathode

A cathode is the electrode from which a conventional current leaves a device.

The Anode, then, is the terminal where current enters.

## Commonly Chosen Numbers

### E Series
Used in electronics component values

#### E3
1.0, 2.2, 4.7,

10, 22, 47,

100, 220, 470,

1 k, 2.2 k, 4.7 k,

10 k, 22 k, 47 k,

100 k, 220 k, 470 k,

1 M, 2.2 M, 4.7 M,

10 M

#### E6

1.0, 1.5, 2.2, 3.3, 4.7, 6.8,

10, 15, 22, 33, 47, 68,

100, 150, 220, 330, 470, 680,

1 k, 1.5 k, 2.2 k, 3.3 k, 4.7 k, 6.8 k,

10 k, 15 k, 22 k, 33 k, 47 k, 68 k,

100 k, 150 k, 220 k, 330 k, 470 k, 680 k,

1 M, 1.5 M, 2.2 M, 3.3 M, 4.7 M, 6.8 M,

10 M

### Renard Series
Commonly used in choosing sizes of things.

#### R5
1.00, 1.60, 2.50, 4.00, 6.30

#### R10

1.00, 1.25, 1.60, 2.00, 2.50, 3.15, 4.00, 5.00, 6.30, 8.00

#### R20

1.00, 1.25, 1.60, 2.00, 2.50, 3.15, 4.00, 5.00, 6.30, 8.00
1.12, 1.40, 1.80, 2.24, 2.80, 3.55, 4.50, 5.60, 7.10, 9.00

#### R40
1.00, 1.25, 1.60, 2.00, 2.50, 3.15, 4.0, 5.00, 6.30, 8.00
1.06, 1.32, 1.70, 2.12, 2.65, 3.35, 4.25, 5.30, 6.70, 8.50
1.12, 1.40, 1.80, 2.24, 2.80, 3.55, 4.50, 5.60, 7.10, 9.00
1.18, 1.50, 1.90, 2.36, 3.00, 3.75, 4.75, 6.00, 7.50, 9.50

#### R80
1.00, 1.25, 1.60, 2.00, 2.50, 3.15, 4.00, 5.00, 6.30, 8.00
1.03, 1.28, 1.65, 2.06, 2.58, 3.25, 4.12, 5.15, 6.50, 8.25
1.06, 1.32, 1.70, 2.12, 2.65, 3.35, 4.25, 5.30, 6.70, 8.50
1.09, 1.36, 1.75, 2.18, 2.72, 3.45, 4.37, 5.45, 6.90, 8.75
1.12, 1.40, 1.80, 2.24, 2.80, 3.55, 4.50, 5.60, 7.10, 9.00
1.15, 1.45, 1.85, 2.30, 2.90, 3.65, 4.62, 5.80, 7.30, 9.25
1.18, 1.50, 1.90, 2.36, 3.00, 3.75, 4.75, 6.00, 7.50, 9.50
1.22, 1.55, 1.95, 2.43, 3.07, 3.87, 4.87, 6.15, 7.75, 9.75


## Blinkenlichten

```
ACHTUNG!
ALLES TURISTEN UND NONTEKNISCHEN LOOKENSPEEPERS!
DAS KOMPUTERMASCHINE IST NICHT FÜR DER GEFINGERPOKEN UND MITTENGRABEN!
ODERWISE IST EASY TO SCHNAPPEN DER SPRINGENWERK, BLOWENFUSEN UND
POPPENCORKEN MIT SPITZENSPARKEN.

IST NICHT FÜR GEWERKEN BEI DUMMKOPFEN. DER RUBBERNECKEN SIGHTSEEREN KEEPEN DAS
COTTONPICKEN HÄNDER IN DAS POCKETS MUSS.
ZO RELAXEN UND WATSCHEN DER BLINKENLICHTEN.
```

## This is not a place of honor

This place is a message... and part of a system of messages... pay attention to it!

Sending this message was important to us. We considered ourselves to be a powerful culture.

This place is not a place of honor... no highly esteemed deed is commemorated here... nothing valued is here.

What is here was dangerous and repulsive to us. This message is a warning about danger.

The danger is in a particular location... it increases towards a center... the center of danger is here... of a particular size and shape, and below us.

The danger is still present, in your time, as it was in ours.

The danger is to the body, and it can kill.

The form of the danger is an emanation of energy.

The danger is unleashed only if you substantially disturb this place physically. This place is best shunned and left uninhabited.


## Akin's Laws of Spacecraft Design

https://spacecraft.ssl.umd.edu/akins_laws.html


1. Engineering is done with numbers. Analysis without numbers is only an opinion.

2. To design a spacecraft right takes an infinite amount of effort. This is why it's a good idea to design them to operate when some things are wrong .

3. Design is an iterative process. The necessary number of iterations is one more than the number you have currently done. This is true at any point in time.

4. Your best design efforts will inevitably wind up being useless in the final design. Learn to live with the disappointment.

5. (Miller's Law) Three points determine a curve.

6. (Mar's Law) Everything is linear if plotted log-log with a fat magic marker.

7. At the start of any design effort, the person who most wants to be team leader is least likely to be capable of it.

8. In nature, the optimum is almost always in the middle somewhere. Distrust assertions that the optimum is at an extreme point.

9. Not having all the information you need is never a satisfactory excuse for not starting the analysis.

10. When in doubt, estimate. In an emergency, guess. But be sure to go back and clean up the mess when the real numbers come along.

11. Sometimes, the fastest way to get to the end is to throw everything out and start over.

12. There is never a single right solution. There are always multiple wrong ones, though.

13. Design is based on requirements. There's no justification for designing something one bit "better" than the requirements dictate.

14. (Edison's Law) "Better" is the enemy of "good".

15. (Shea's Law) The ability to improve a design occurs primarily at the interfaces. This is also the prime location for screwing it up.

16. The previous people who did a similar analysis did not have a direct pipeline to the wisdom of the ages. There is therefore no reason to believe their analysis over yours. There is especially no reason to present their analysis as yours.

17. The fact that an analysis appears in print has no relationship to the likelihood of its being correct.

18. Past experience is excellent for providing a reality check. Too much reality can doom an otherwise worthwhile design, though.

19. The odds are greatly against you being immensely smarter than everyone else in the field. If your analysis says your terminal velocity is twice the speed of light, you may have invented warp drive, but the chances are a lot better that you've screwed up.

20. A bad design with a good presentation is doomed eventually. A good design with a bad presentation is doomed immediately.

21. (Larrabee's Law) Half of everything you hear in a classroom is crap. Education is figuring out which half is which.

22. When in doubt, document. (Documentation requirements will reach a maximum shortly after the termination of a program.)

23. The schedule you develop will seem like a complete work of fiction up until the time your customer fires you for not meeting it.

24. It's called a "Work Breakdown Structure" because the Work remaining will grow until you have a Breakdown, unless you enforce some Structure on it.

25. (Bowden's Law) Following a testing failure, it's always possible to refine the analysis to show that you really had negative margins all along.

26. (Montemerlo's Law) Don't do nuthin' dumb.

27. (Varsi's Law) Schedules only move in one direction.

28. (Ranger's Law) There ain't no such thing as a free launch.

29. (von Tiesenhausen's Law of Program Management) To get an accurate estimate of final program requirements, multiply the initial time estimates by pi, and slide the decimal point on the cost estimates one place to the right.

30. (von Tiesenhausen's Law of Engineering Design) If you want to have a maximum effect on the design of a new engineering system, learn to draw. Engineers always wind up designing the vehicle to look like the initial artist's concept.

31. (Mo's Law of Evolutionary Development) You can't get to the moon by climbing successively taller trees.

32. (Atkin's Law of Demonstrations) When the hardware is working perfectly, the really important visitors don't show up.

33. (Patton's Law of Program Planning) A good plan violently executed now is better than a perfect plan next week.

34. (Roosevelt's Law of Task Planning) Do what you can, where you are, with what you have.

35. (de Saint-Exupery's Law of Design) A designer knows that they have achieved perfection not when there is nothing left to add, but when there is nothing left to take away.

36. Any run-of-the-mill engineer can design something which is elegant. A good engineer designs systems to be efficient. A great engineer designs them to be effective.

37. (Henshaw's Law) One key to success in a mission is establishing clear lines of blame.

38. Capabilities drive requirements, regardless of what the systems engineering textbooks say.

39. Any exploration program which "just happens" to include a new launch vehicle is, de facto, a launch vehicle program.

39. (alternate formulation) The three keys to keeping a new human space program affordable and on schedule:
       1)  No new launch vehicles.
       2)  No new launch vehicles.
       3)  Whatever you do, don't develop any new launch vehicles.

40. (McBryan's Law) You can't make it better until you make it work.

41. There's never enough time to do it right, but somehow, there's always enough time to do it over.

42. If there's not a flight program, there's no money.
      If there is a flight program, there's no time.

43. You really understand something the third time you see it (or the first time you teach it.)

44. (Lachance's Law) "Plenty of time" becomes "not enough time" in a very short time.

45. Space is a completely unforgiving environment. If you screw up the engineering, somebody dies (and there's no partial credit because most of the analysis was right...)

I've been involved in spacecraft and space systems design and development for my entire career, including teaching the senior-level capstone spacecraft design course, for ten years at MIT and now at the University of Maryland for more than three decades. These are some bits of wisdom that I have gleaned during that time, some by picking up on the experience of others, but mostly by screwing up myself. I originally wrote these up and handed them out to my senior design class, as a strong hint on how best to survive my design experience. Months later, I get a phone call from a friend in California complimenting me on the Laws, which he saw on a "joke-of-the-day" listserve. Since then, I'm aware of half a dozen sites around the world that present various editions of the Laws, and even one site which has converted them (without attribution, of course) to the Laws of Certified Public Accounting. (Don't ask...) Anyone is welcome to link to these, use them, post them, send me suggestions of additional laws, but I do maintain that this is the canonical set of Akin's Laws...


# Crew Resource Management

## 🚨 Hazardous Attitudes

😡  **Anti-authority**:  "Don't tell me what to do!"
(This attitude can happen even without traditional authority figures)

😱  **Impulsivity**:  "We gotta do something now!!"

☺️  **Invulnerability**:  "Tragedy is something you hear about on the news, it couldn't happen to me"

🎖️  **Overconfidence**:  "I can do it! I can handle anything!"

😞  **Resignation**:  "There's no use even trying"

⌚  **Pressing**:  "Let's hurry this up, I want to go home and have dinner"

😎  **Airshow Syndrome**:  "Hold my beer and watch this!"


## 💩 Loss of Situational Awareness

🤔  **Ambiguity**:  Your understanding of the situation is full of open questions

🙂‍↔️  **Distraction**:  Focus is being drawn to less important things, perhaps without anyone noticing

🧐  **Fixation**:  One item absolutely dominates thought and conversation

🫨  **Overload**:  New information and events are piling on faster than anyone can respond

😌  **Complacency**:  Nothing is apparently going wrong, but close attention is not being paid and standards are being relaxed

🙃  **Improper Procedure**:  Things are done in unusual ways without documentation or justification

😐  **Unresolved Discrepancy**:  A backlog of issues or conflicts that have not been attended to

😴  **Nobody flying the plane**:  There is nobody managing moment to moment operations, possibly because nobody is sure who is meant to be doing so.


## 📣 Mistakes when Speaking or Writing

🤪  **Failure to establish context**: "Pull that line" could mean multiple things

😗  **Providing biased information** or **intentionally withholding information**, such as saying "There's enough fuel left", rather than giving a specific amount

🤫 **Being unwilling to repeat or clarify** if the listener did not understand

😠  **Aggressive, disrespectful, or malicious communication**, sprinkling in personal insults, using disrespectful or disinterested body language.


## 🌽 Mistakes when Listening

🥱  **Making your mind up before listening**: "Anything this person says is obviously trash"

🤠  **Poor preparation**: Listening is a conscious activity that may involve taking notes, or intentionally pausing distractions

🙄  **Ignoring Nonverbal Signals**

😊 **Not asking for clarification**: often caused by unwillingness to admit you don't already know something

🤬  **Creating a climate of fear** by always responding negatively, verbally or otherwise.


## Error Management

### 🏋  Maintain Proficiency

Failure to maintain proficiency removes a critical layer of redundancy, even though things may appear "safe enough" due to luck or technology.


### 📣  Speak Up!

Don't ignore unsafe conditions or allow yourself to be pushed into dangerous situations.

### ✅  Follow Protocol

> Slow is Smooth and Smooth is Fast

Even small changes may have unknown consequences, especially in the face of unknown external events, and ignoring the rules when you think they don't matter can make it more likely that you will forget something when they do.

### 🦗  Minimize Distraction

Just "Being careful" is a overused cliche. Nobody is perfectly reliable or capable.

What you can  do is remove distractions, to maximize the ability you do have. Do not leave distractions and hazards around, and plan critical tasks for times when you are well rested, not dehydrated, hungry, angry, or otherwise impaired.

### 🤝  Plan Ahead

> Proper Planning Prevents Poor Performance

Treat potential problems seriously even if you do not know for certain they will occur, do as much as possible ahead of time under controlled conditions.

### 👁  Maintain Situational Awareness

Especially with hands-off and automated processes, it is very easy to become complacent.  Things that are hard to observe, or which cannot be inspected once finished can also be sources of trouble. Who hasn't wondered if they left the oven on?

### 🧑‍🏭️  Effectively use Resources

Do not show off by doing things "the hard way".  Use the appropriate tools and protective equipment (Even if you have to stop and get them!), get a second pair of eyes on important tasks, and set timers for things that may be forgotten.

### 🛡 Multiple Layers of Safety

> Two is one, one is none, and three is a good start

Avoid relying on any one device or method whenever possible. Avoid situations where one mistake
will cause major problems, even if you think "nobody would ever make that mistake".

Even the experts can press the wrong button or misidentify a mushroom, and there are many shop teachers who have lost a finger.

Backup plans that are very different from the primary are less likely to be affected by the same causes of failure at the same time.
